[nautilus-actions/file-manager-actions] NAGConfMonitor class is renamed to FMAGConfMonitor



commit 5d990e907c05c68a5e6a128369cf35e4e0ef3d8f
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Sep 7 21:51:12 2015 +0200

    NAGConfMonitor class is renamed to FMAGConfMonitor

 src/api/Makefile.am                                |    2 +-
 .../{na-gconf-monitor.h => fma-gconf-monitor.h}    |   40 +++++-----
 src/core/Makefile.am                               |    2 +-
 .../{na-gconf-monitor.c => fma-gconf-monitor.c}    |   86 ++++++++++----------
 src/io-gconf/nagp-gconf-provider.c                 |    8 +-
 src/io-gconf/nagp-gconf-provider.h                 |    2 +-
 6 files changed, 70 insertions(+), 70 deletions(-)
---
diff --git a/src/api/Makefile.am b/src/api/Makefile.am
index df3805d..4993b5f 100644
--- a/src/api/Makefile.am
+++ b/src/api/Makefile.am
@@ -42,7 +42,7 @@ api_include_HEADERS = \
        fma-data-boxed.h                                                                                \
        fma-data-def.h                                                                          \
        fma-data-types.h                                                                                \
-       na-gconf-monitor.h                                                                      \
+       fma-gconf-monitor.h                                                                     \
        na-gconf-utils.h                                                                        \
        na-icontext.h                                                                           \
        na-iduplicable.h                                                                        \
diff --git a/src/api/na-gconf-monitor.h b/src/api/fma-gconf-monitor.h
similarity index 56%
rename from src/api/na-gconf-monitor.h
rename to src/api/fma-gconf-monitor.h
index 0001d77..6599a0d 100644
--- a/src/api/na-gconf-monitor.h
+++ b/src/api/fma-gconf-monitor.h
@@ -27,16 +27,16 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __FILE_MANAGER_ACTIONS_API_NA_GCONF_MONITOR_H__
-#define __FILE_MANAGER_ACTIONS_API_NA_GCONF_MONITOR_H__
+#ifndef __FILE_MANAGER_ACTIONS_API_FMA_GCONF_MONITOR_H__
+#define __FILE_MANAGER_ACTIONS_API_FMA_GCONF_MONITOR_H__
 
 #ifdef HAVE_GCONF
 #ifdef NA_ENABLE_DEPRECATED
 /**
  * SECTION: gconf-monitor
- * @title: NAGConfMonitor
+ * @title: FMAGConfMonitor
  * @short_description: The GConf Monitoring Class Definition
- * @include: file-manager-actions/na-gconf-monitor.h
+ * @include: file-manager-actions/fma-gconf-monitor.h
  *
  * This class manages the GConf monitoring.
  * It is used to monitor both the GConf provider and the GConf runtime
@@ -50,39 +50,39 @@
 
 G_BEGIN_DECLS
 
-#define NA_GCONF_MONITOR_TYPE                ( na_gconf_monitor_get_type())
-#define NA_GCONF_MONITOR( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, NA_GCONF_MONITOR_TYPE, 
NAGConfMonitor ))
-#define NA_GCONF_MONITOR_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, NA_GCONF_MONITOR_TYPE, 
NAGConfMonitorClass ))
-#define NA_IS_GCONF_MONITOR( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_GCONF_MONITOR_TYPE ))
-#define NA_IS_GCONF_MONITOR_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NA_GCONF_MONITOR_TYPE ))
-#define NA_GCONF_MONITOR_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), NA_GCONF_MONITOR_TYPE, 
NAGConfMonitorClass ))
+#define FMA_GCONF_MONITOR_TYPE                ( fma_gconf_monitor_get_type())
+#define FMA_GCONF_MONITOR( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, FMA_GCONF_MONITOR_TYPE, 
FMAGConfMonitor ))
+#define FMA_GCONF_MONITOR_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, FMA_GCONF_MONITOR_TYPE, 
FMAGConfMonitorClass ))
+#define FMA_IS_GCONF_MONITOR( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, FMA_GCONF_MONITOR_TYPE ))
+#define FMA_IS_GCONF_MONITOR_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), FMA_GCONF_MONITOR_TYPE ))
+#define FMA_GCONF_MONITOR_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), 
FMA_GCONF_MONITOR_TYPE, FMAGConfMonitorClass ))
 
-typedef struct _NAGConfMonitorPrivate        NAGConfMonitorPrivate;
+typedef struct _FMAGConfMonitorPrivate        FMAGConfMonitorPrivate;
 
 typedef struct {
        /*< private >*/
        GObject                parent;
-       NAGConfMonitorPrivate *private;
+       FMAGConfMonitorPrivate *private;
 }
-       NAGConfMonitor;
+       FMAGConfMonitor;
 
-typedef struct _NAGConfMonitorClassPrivate   NAGConfMonitorClassPrivate;
+typedef struct _FMAGConfMonitorClassPrivate   FMAGConfMonitorClassPrivate;
 
 typedef struct {
        /*< private >*/
        GObjectClass                parent;
-       NAGConfMonitorClassPrivate *private;
+       FMAGConfMonitorClassPrivate *private;
 }
-       NAGConfMonitorClass;
+       FMAGConfMonitorClass;
 
-GType           na_gconf_monitor_get_type( void );
+GType           fma_gconf_monitor_get_type( void );
 
-NAGConfMonitor *na_gconf_monitor_new( const gchar *path, GConfClientNotifyFunc handler, gpointer user_data );
+FMAGConfMonitor *fma_gconf_monitor_new( const gchar *path, GConfClientNotifyFunc handler, gpointer user_data 
);
 
-void            na_gconf_monitor_release_monitors( GList *monitors );
+void            fma_gconf_monitor_release_monitors( GList *monitors );
 
 G_END_DECLS
 
 #endif /* NA_ENABLE_DEPRECATED */
 #endif /* HAVE_GCONF */
-#endif /* __FILE_MANAGER_ACTIONS_API_NA_GCONF_MONITOR_H__ */
+#endif /* __FILE_MANAGER_ACTIONS_API_FMA_GCONF_MONITOR_H__ */
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index dd213e1..6a4d19d 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -70,7 +70,7 @@ libna_core_la_SOURCES = \
        na-factory-provider.h                                                           \
        na-gconf-migration.c                                                            \
        na-gconf-migration.h                                                            \
-       na-gconf-monitor.c                                                                      \
+       fma-gconf-monitor.c                                                                     \
        na-gconf-utils.c                                                                        \
        na-gnome-vfs-uri.c                                                                      \
        na-gnome-vfs-uri.h                                                                      \
diff --git a/src/io-gconf/nagp-gconf-provider.c b/src/io-gconf/nagp-gconf-provider.c
index 1fb30ae..e00bb79 100644
--- a/src/io-gconf/nagp-gconf-provider.c
+++ b/src/io-gconf/nagp-gconf-provider.c
@@ -36,7 +36,7 @@
 
 #include <api/na-ifactory-provider.h>
 #include <api/na-iio-provider.h>
-#include <api/na-gconf-monitor.h>
+#include <api/fma-gconf-monitor.h>
 
 #include "nagp-gconf-provider.h"
 #include "nagp-reader.h"
@@ -179,7 +179,7 @@ instance_dispose( GObject *object )
 
 #ifdef NA_ENABLE_DEPRECATED
                /* release the GConf monitoring */
-               na_gconf_monitor_release_monitors( self->private->monitors );
+               fma_gconf_monitor_release_monitors( self->private->monitors );
 #endif
 
                /* release the GConf connexion */
@@ -295,13 +295,13 @@ install_monitors( NagpGConfProvider *provider )
         * actions and profiles definitions
         */
        list = g_list_prepend( list,
-                       na_gconf_monitor_new(
+                       fma_gconf_monitor_new(
                                        NAGP_CONFIGURATIONS_PATH,
                                        ( GConfClientNotifyFunc ) config_path_changed_cb,
                                        provider ));
 
        list = g_list_prepend( list,
-                       na_gconf_monitor_new(
+                       fma_gconf_monitor_new(
                                        NAGP_SCHEMAS_PATH,
                                        ( GConfClientNotifyFunc ) config_path_changed_cb,
                                        provider ));
diff --git a/src/io-gconf/nagp-gconf-provider.h b/src/io-gconf/nagp-gconf-provider.h
index 249a5ab..0b316e6 100644
--- a/src/io-gconf/nagp-gconf-provider.h
+++ b/src/io-gconf/nagp-gconf-provider.h
@@ -39,7 +39,7 @@
  * the GConf subsystem as an #NAIIOProvider. As this, it should only be
  * used through the #NAIIOProvider interface.
  *
- * #NagpGConfProvider uses #NAGConfMonitor to watch at the configuration
+ * #NagpGConfProvider uses #FMAGConfMonitor to watch at the configuration
  * tree. Modifications are notified to the #NAIIOProvider interface.
  */
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/core/na-gconf-monitor.c b/src/core/fma-gconf-monitor.c
similarity index 74%
rename from src/core/na-gconf-monitor.c
rename to src/core/fma-gconf-monitor.c
index 29bc63a..ae2afae 100644
--- a/src/core/na-gconf-monitor.c
+++ b/src/core/fma-gconf-monitor.c
@@ -31,20 +31,20 @@
 #include <config.h>
 #endif
 
-#include <api/na-gconf-monitor.h>
+#include <api/fma-gconf-monitor.h>
 
 #ifdef HAVE_GCONF
 #ifdef NA_ENABLE_DEPRECATED
 
 /* private class data
  */
-struct _NAGConfMonitorClassPrivate {
+struct _FMAGConfMonitorClassPrivate {
        void *empty;                                            /* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct _NAGConfMonitorPrivate {
+struct _FMAGConfMonitorPrivate {
        gboolean              dispose_has_run;
        GConfClient          *gconf;
        gchar                *path;
@@ -57,16 +57,16 @@ struct _NAGConfMonitorPrivate {
 static GObjectClass *st_parent_class = NULL;
 
 static GType register_type( void );
-static void  class_init( NAGConfMonitorClass *klass );
+static void  class_init( FMAGConfMonitorClass *klass );
 static void  instance_init( GTypeInstance *instance, gpointer klass );
 static void  instance_dispose( GObject *object );
 static void  instance_finalize( GObject *object );
 
-static guint install_monitor( NAGConfMonitor *monitor );
-static void  release_monitor( NAGConfMonitor *monitor );
+static guint install_monitor( FMAGConfMonitor *monitor );
+static void  release_monitor( FMAGConfMonitor *monitor );
 
 GType
-na_gconf_monitor_get_type( void )
+fma_gconf_monitor_get_type( void )
 {
        static GType object_type = 0;
 
@@ -80,32 +80,32 @@ na_gconf_monitor_get_type( void )
 static GType
 register_type( void )
 {
-       static const gchar *thisfn = "na_gconf_monitor_register_type";
+       static const gchar *thisfn = "fma_gconf_monitor_register_type";
        GType type;
 
        static GTypeInfo info = {
-               sizeof( NAGConfMonitorClass ),
+               sizeof( FMAGConfMonitorClass ),
                NULL,
                NULL,
                ( GClassInitFunc ) class_init,
                NULL,
                NULL,
-               sizeof( NAGConfMonitor ),
+               sizeof( FMAGConfMonitor ),
                0,
                ( GInstanceInitFunc ) instance_init
        };
 
        g_debug( "%s", thisfn );
 
-       type = g_type_register_static( G_TYPE_OBJECT, "NAGConfMonitor", &info, 0 );
+       type = g_type_register_static( G_TYPE_OBJECT, "FMAGConfMonitor", &info, 0 );
 
        return( type );
 }
 
 static void
-class_init( NAGConfMonitorClass *klass )
+class_init( FMAGConfMonitorClass *klass )
 {
-       static const gchar *thisfn = "na_gconf_monitor_class_init";
+       static const gchar *thisfn = "fma_gconf_monitor_class_init";
        GObjectClass *object_class;
 
        g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
@@ -116,22 +116,22 @@ class_init( NAGConfMonitorClass *klass )
        object_class->dispose = instance_dispose;
        object_class->finalize = instance_finalize;
 
-       klass->private = g_new0( NAGConfMonitorClassPrivate, 1 );
+       klass->private = g_new0( FMAGConfMonitorClassPrivate, 1 );
 }
 
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
-       static const gchar *thisfn = "na_gconf_monitor_instance_init";
-       NAGConfMonitor *self;
+       static const gchar *thisfn = "fma_gconf_monitor_instance_init";
+       FMAGConfMonitor *self;
 
-       g_return_if_fail( NA_IS_GCONF_MONITOR( instance ));
+       g_return_if_fail( FMA_IS_GCONF_MONITOR( instance ));
 
        g_debug( "%s: instance=%p (%s), klass=%p",
                        thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
-       self = NA_GCONF_MONITOR( instance );
+       self = FMA_GCONF_MONITOR( instance );
 
-       self->private = g_new0( NAGConfMonitorPrivate, 1 );
+       self->private = g_new0( FMAGConfMonitorPrivate, 1 );
 
        self->private->gconf = gconf_client_get_default();
 
@@ -141,12 +141,12 @@ instance_init( GTypeInstance *instance, gpointer klass )
 static void
 instance_dispose( GObject *object )
 {
-       static const gchar *thisfn = "na_gconf_monitor_instance_dispose";
-       NAGConfMonitor *self;
+       static const gchar *thisfn = "fma_gconf_monitor_instance_dispose";
+       FMAGConfMonitor *self;
 
-       g_return_if_fail( NA_IS_GCONF_MONITOR( object ));
+       g_return_if_fail( FMA_IS_GCONF_MONITOR( object ));
 
-       self = NA_GCONF_MONITOR( object );
+       self = FMA_GCONF_MONITOR( object );
 
        if( !self->private->dispose_has_run ){
 
@@ -169,14 +169,14 @@ instance_dispose( GObject *object )
 static void
 instance_finalize( GObject *object )
 {
-       static const gchar *thisfn = "na_gconf_monitor_instance_finalize";
-       NAGConfMonitor *self;
+       static const gchar *thisfn = "fma_gconf_monitor_instance_finalize";
+       FMAGConfMonitor *self;
 
-       g_return_if_fail( NA_IS_GCONF_MONITOR( object ));
+       g_return_if_fail( FMA_IS_GCONF_MONITOR( object ));
 
        g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
-       self = NA_GCONF_MONITOR( object );
+       self = FMA_GCONF_MONITOR( object );
 
        g_free( self->private->path );
        g_free( self->private );
@@ -188,7 +188,7 @@ instance_finalize( GObject *object )
 }
 
 /**
- * na_gconf_monitor_new:
+ * fma_gconf_monitor_new:
  * @path: the absolute path to monitor.
  * @handler: the function to be triggered by the monitor.
  * @user_data: data to pass to the @handler.
@@ -198,21 +198,21 @@ instance_finalize( GObject *object )
  * This monitoring will only be stopped when object is released, via
  * g_object_unref().
  *
  * Returns: a new #NAGConfMonitor object, which will monitor the given path,
  * triggeering the @handler in case of modifications.
  *
  * Since: 2.30
  * Deprecated: 3.1
  */
-NAGConfMonitor *
-na_gconf_monitor_new( const gchar *path, GConfClientNotifyFunc handler, gpointer user_data )
+FMAGConfMonitor *
+fma_gconf_monitor_new( const gchar *path, GConfClientNotifyFunc handler, gpointer user_data )
 {
-       static const gchar *thisfn = "na_gconf_monitor_new";
-       NAGConfMonitor *monitor;
+       static const gchar *thisfn = "fma_gconf_monitor_new";
+       FMAGConfMonitor *monitor;
 
        g_debug( "%s: path=%s, user_data=%p", thisfn, path, ( void * ) user_data );
 
-       monitor = g_object_new( NA_GCONF_MONITOR_TYPE, NULL );
+       monitor = g_object_new( FMA_GCONF_MONITOR_TYPE, NULL );
 
        monitor->private->path = g_strdup( path );
        monitor->private->preload = GCONF_CLIENT_PRELOAD_RECURSIVE;
@@ -225,13 +225,13 @@ na_gconf_monitor_new( const gchar *path, GConfClientNotifyFunc handler, gpointer
 }
 
 static guint
-install_monitor( NAGConfMonitor *monitor )
+install_monitor( FMAGConfMonitor *monitor )
 {
-       static const gchar *thisfn = "na_gconf_monitor_install_monitor";
+       static const gchar *thisfn = "fma_gconf_monitor_install_monitor";
        GError *error = NULL;
        guint notify_id;
 
-       g_return_val_if_fail( NA_IS_GCONF_MONITOR( monitor ), 0 );
+       g_return_val_if_fail( FMA_IS_GCONF_MONITOR( monitor ), 0 );
        g_return_val_if_fail( !monitor->private->dispose_has_run, 0 );
 
        gconf_client_add_dir(
@@ -264,8 +264,8 @@ install_monitor( NAGConfMonitor *monitor )
 }
 
 /**
- * na_gconf_monitor_release_monitors:
- * @monitors: a list of #NAGConfMonitors.
+ * fma_gconf_monitor_release_monitors:
+ * @monitors: a list of #FMAGConfMonitors.
  *
  * Release allocated monitors.
  *
@@ -273,7 +273,7 @@ install_monitor( NAGConfMonitor *monitor )
  * Deprecated: 3.1
  */
 void
-na_gconf_monitor_release_monitors( GList *monitors )
+fma_gconf_monitor_release_monitors( GList *monitors )
 {
        g_list_foreach( monitors, ( GFunc ) g_object_unref, NULL );
        g_list_free( monitors );
@@ -283,12 +283,12 @@ na_gconf_monitor_release_monitors( GList *monitors )
  * this is called by instance_dispose, before setting dispose_has_run
  */
 static void
-release_monitor( NAGConfMonitor *monitor )
+release_monitor( FMAGConfMonitor *monitor )
 {
-       static const gchar *thisfn = "na_gconf_monitor_release_monitor";
+       static const gchar *thisfn = "fma_gconf_monitor_release_monitor";
        GError *error = NULL;
 
-       g_return_if_fail( NA_IS_GCONF_MONITOR( monitor ));
+       g_return_if_fail( FMA_IS_GCONF_MONITOR( monitor ));
 
        if( !monitor->private->dispose_has_run ){
 
@@ -198,21 +198,21 @@ instance_finalize( GObject *object )
  * g_object_unref().
  *
- * Returns: a new #NAGConfMonitor object, which will monitor the given path,
+ * Returns: a new #FMAGConfMonitor object, which will monitor the given path,
  * triggeering the @handler in case of modifications.
  *